
from numpy import array, norm, dot, cross, arccos, arctan2 

class Molecule:
    def __init__(self, atomlist):
        self.positions = atomlist
    def setGeometry(self, atomlist):
        self.positions = atomlist
    def setCartesianForces(self, forcelist):
        self.forces = forcelist
    def getCenterOfMass(self):
        pass
    def getIntertiaTensor(self):
        pass
    def getEulerAngles(self):
        """
        Find the Euler angles describing the orientation of
        the atoms relative to the principal axes of inertia.
        The angles are obtained from the rotation matrix that
        diagonalizes the tensor of inertia.
        """

#The following functions can be used to define internal coordinates

def distance(atom1, atom2):
    """
    distance between two atomic centers

    Parameters:
    ===========
    atom1:  tuple (Z1,(x1,y1,z1))
    atom2:  tuple (Z2,(x2,y2,z2))

    Returns:
    ========
    d = sqrt((x2-x1)^2 + (y2-y1)^2 + (z2-z1)^2)
    """
    (Z1,pos1) = atom1
    (Z2,pos2) = atom2
    d = norm(array(pos1) - array(pos2))
    return d

def angle(atom1, atom2, atom3):
    """
    angle between vectors atom1->atom2 and atom1->atom3
    """
    v12 = array(atom2[1]) - array(atom1[1])
    v13 = array(atom3[1]) - array(atom1[1])
    a = arccos(dot(v12,v13)/(norm(v12)*norm(v13)))
    return a

def dihedral_angle(atom1, atom2, atom3, atom4):
    """
    dihedral angle between the planes spanned by atom1->atom2, atom2->atom3
    and atom2->atom3, atom3->atom4
    """
    b1 = array(atom2[1]) - array(atom1[1])
    b2 = array(atom3[1]) - array(atom2[1])
    b3 = array(atom4[1]) - array(atom3[1])
    n12 = cross(b1,b2)
    n23 = cross(b2,b3)
    e1 = b1/norm(b1)
    e2 = n12/norm(n12)
    """e1 and e2 form a orthonormal basis of a plane,
    the dihedral angle is the polar angle of the projection
    of n23 onto this plane."""
    dihedral = arctan2(dot(e2,n23), dot(e1,n23))
    return dihedral

#internal_coordinate = lambda atoms: distance(atoms[0], atoms[1])

if __name__ == "__main__":
    pass
